tests Package
=============

:mod:`tests` Package
--------------------

.. automodule:: worq.tests
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_core` Module
-----------------------

.. automodule:: worq.tests.test_core
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_examples` Module
---------------------------

.. automodule:: worq.tests.test_examples
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_task` Module
-----------------------

.. automodule:: worq.tests.test_task
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`util` Module
------------------

.. automodule:: worq.tests.util
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    worq.tests.pool

